﻿'-------------------------------------------------------------------------------
' C U S T O M I Z I N G   T H E   G R I D   A N D   A D O   I N   C O D E
'                                 Project 1-A  OOP Version
'                                            Ron Kessler
'                              Created 8/11/2010 For VB 2008
'                                     Study Group Version
'-------------------------------------------------------------------------------
'updated 8/18/2010

'8/18/2010    Modified UpdateDB so it clears the DS and reloads all the records to update the grid

'Notes:
'   Be sure to copy my customers.mdb into the root of your solution. Cancel the Wizard when it tries to add datasources.
'   Be sure to change your target CPU to x86 if you are designing on a 64 bit version of Windows!
'This app shows you how to:
'1. format the grid in code.
'2. Create two helper classes for the formatting code and the ADO objects
'3. The purpose of this is to show you how to move stuff out of your UI
'4. Be sure to study the code carefully so you understand what all the pieces are doing.



Option Explicit On

'---import the ADO Namespaces
Imports System.Data
Imports System.Data.OleDb        'for Access  If you use SQL then Import System.Data.SqlClient

'---import the two classes I created so you do not have to type their complete name each time!
Imports _1_A_CustomizingMrGridInCode_Access.GridRoutines  'my helper class I created
Imports _1_A_CustomizingMrGridInCode_Access.ADORoutines  'ditto

Public Class frmMain
    '---a flag to let me know if the db update worked or not. It is used to manage my status label
    Dim updatedDB As Boolean = False


#Region "Form Load"
    Private Sub frmMain_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        '---get all records to start with
        FillDB()

    End Sub
#End Region

#Region "Fill DB"
    Private Sub FillDB()

        '---called from form_load to get all records
        'ADO objects are declared in ADORoutines.vb class & are shared so you do not have to instantiate an object from the class!
        Try

            '---FILL THE DATA ADAPTER
            dataAdapter.Fill(customersDS, "myCustomers")    'myCustomers refers to the table name in the DS

            '---Bind the grid
            DataGridView1.DataSource = ADORoutines.customersDS
            DataGridView1.DataMember = "myCustomers"

            '---Format the look of Mr. Grid!
            GridRoutines.FormatGrid(DataGridView1)

        Catch ex As Exception
            MessageBox.Show("I could not read the database..." & ex.Message, "System Message", _
                            MessageBoxButtons.OK, MessageBoxIcon.Error)
            Me.Close()

        End Try
    End Sub
#End Region

#Region "Update the DB"
    Private Sub UpdateDB()
        Try
            Dim dataAdapter As New OleDbDataAdapter(SQL_SELECT, Conn)
            Dim oleCmdBuilder As New OleDbCommandBuilder(dataAdapter)
            oleCmdBuilder.GetUpdateCommand()
            dataAdapter.Update(customersDS.Tables("myCustomers"))
            updatedDB = True

            '---updated 8/18/2010
            customersDS.Clear()  'clear all the records so we do not get double records
            FillDB()                     'show the changes in Mr.Grid
            '-----------------------
        Catch ex As Exception
            MessageBox.Show("Error while saving...." & ex.Message, "Database Error", _
                            MessageBoxButtons.OK, MessageBoxIcon.Error)
            updatedDB = False
        End Try
        HandleStatusStrip(updatedDB)
    End Sub
#End Region

#Region "Handle Status Strip Msg"
    Private Sub HandleStatusStrip(ByVal status As Boolean)
        If status Then
            lblStatus.Text = "Your data has been saved."
        Else
            lblStatus.Text = String.Empty
        End If
    End Sub

    Private Sub DataGridView1_CellClick(ByVal sender As System.Object, ByVal e As System.Windows.Forms.DataGridViewCellEventArgs) Handles DataGridView1.CellClick
        '---they clicked on any cell so let's clear my status msg
        HandleStatusStrip(False)
    End Sub
#End Region

#Region "Confirm Delete"
    Private Sub DataGridView1_UserDeletingRow(ByVal sender As System.Object, ByVal e As System.Windows.Forms.DataGridViewRowCancelEventArgs) Handles DataGridView1.UserDeletingRow

        '---when they push delete, this fires. You can delete multiple rows at a time!
        If MessageBox.Show("Are you sure?", "Ready to delete", MessageBoxButtons.YesNo, MessageBoxIcon.Question, MessageBoxDefaultButton.Button2) = Windows.Forms.DialogResult.Yes Then
            e.Cancel = False
            For Each row As DataGridViewRow In DataGridView1.SelectedRows   'just like selected items in a listbox
                If row.IsNewRow = False Then                'no deleting the new/blank row at the bottom!
                    DataGridView1.Rows.Remove(row)
                End If
            Next

        Else
            e.Cancel = True     'they clicked no on the msgbox

        End If
    End Sub
#End Region

#Region "Save changes & Exit"
    Private Sub SaveToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles SaveToolStripMenuItem.Click
        '---clicked Save from File Menu
        UpdateDB()
    End Sub

    Private Sub ExitToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ExitToolStripMenuItem.Click

        '---let's try and make this Kessler proof! If they try to exit and have not saved changes, ask them....

        '---are there changes in the DS that have not been saved?
        If customersDS.HasChanges Then
            If MessageBox.Show("You did not update your records. Do you still want to exit?", "Changes Not Updated", _
                               MessageBoxButtons.YesNo, MessageBoxIcon.Question, _
                               MessageBoxDefaultButton.Button2) = Windows.Forms.DialogResult.Yes Then

                Me.Close()
            End If
        Else
            Me.Close()
        End If
    End Sub
#End Region


End Class
